from setuptools import setup, find_packages # importam setarile pentru un pachet din pachetul instalat in terminal


setup(name='Mypackage-665', description='This is my package', author='me', packages=find_packages(), version='0.0.1')
